Package: rgoogleads
Title: Loading Data from 'Google Ads API'
Version: 0.14.1
Authors@R: 
    c(person(given  = "Alexey",
             family = "Seleznev",
             role   = c("aut", "cre"),
             email  = "selesnow@gmail.com",
             comment = c(ORCID = "0000-0003-0410-7385")),
      person(given = "Netpeak",
             role = c("cph")))
Description: Interface for loading data from 'Google Ads API', 
    see <https://developers.google.com/google-ads/api/docs/start>. 
    Package provide function for authorization and loading reports.
License: MIT + file LICENSE
BugReports: https://github.com/selesnow/rgoogleads/issues
URL: https://selesnow.github.io/rgoogleads/,
        https://selesnow.github.io/rgoogleads/docs/,
        https://github.com/selesnow/rgoogleads
Encoding: UTF-8
Imports: gargle (>= 1.2.0), httr, stringr, rlang, dplyr (>= 1.0.0),
        tidyr (>= 1.0.0), jsonlite, snakecase, cli (>= 3.0.0), pbapply,
        purrr, withr, rlist, rvest (>= 1.0.0), memoise, cachem,
        rappdirs, utils, lifecycle
RoxygenNote: 7.3.2
Suggests: rmarkdown, knitr, DT
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-16 14:04:39 UTC; User
Author: Alexey Seleznev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0410-7385>),
  Netpeak [cph]
Maintainer: Alexey Seleznev <selesnow@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-16 14:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:27:56 UTC; unix
