# export
export(gads_auth)
export(gads_deauth)
export(gads_token)
export(gads_has_token)
export(gads_auth_configure)
export(gads_api_key)
export(gads_oauth_app)
export(gads_auth_cache_path)
export(gads_open_auth_cache_folder)
export(gads_developer_token)
export(gads_user)
export(gads_set_login_customer_id)
export(gads_set_customer_id)
export(gads_get_accessible_customers)
export(gads_customer)
export(gads_get_account_hierarchy)
export(gads_get_report)
export(gads_get_campaigns)
export(gads_get_ad_groups)
export(gads_get_ads)
export(gads_get_ad_group_criterions)
export(gads_get_keywords)
export(gads_get_fields)
export(gads_get_metadata)
export(gads_keyword_plan_historical_metrics)
export(gads_keyword_plan_forecast_timeseries)
export(gads_keyword_plan_forecast_metrics)
export(gads_get_geo_targets)
export(gads_last_request_ids)

# import
import(dplyr)
import(tidyr)
import(stringr)
import(purrr)
import(gargle)
import(snakecase)
import(memoise)
import(cachem)
import(rappdirs)
import(utils)

# import from
importFrom(rlang,"%||%", 'caller_env')
importFrom(httr, GET, POST, content, add_headers, headers)
importFrom(jsonlite, toJSON, fromJSON)
importFrom(cli, cli_alert_info, cli_alert_success, cli_alert_danger, cli_alert_warning, cli_div, cli_abort)
importFrom(pbapply, pblapply)
importFrom(rlist, list.filter)
importFrom(rvest, read_html, html_element, html_attr)
importFrom(utils, read.csv)
