% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_last_request_ids.R
\name{gads_last_request_ids}
\alias{gads_last_request_ids}
\title{Get last API request ID for Google Ads API support ticket}
\usage{
gads_last_request_ids()
}
\value{
Request ID
}
\description{
Get last API request ID for Google Ads API support ticket
}
\examples{
\dontrun{
gads_last_request_ids()
}
}
