% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_fix_names.R
\name{gads_fix_names}
\alias{gads_fix_names}
\title{function for fix names in get_report}
\usage{
gads_fix_names(x)
}
\arguments{
\item{x}{character, column names}
}
\value{
new columns names
}
\description{
function for fix names in get_report
}
