% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_auth.R
\name{gads_deauth}
\alias{gads_deauth}
\title{Suspend authorization}
\usage{
gads_deauth()
}
\value{
only suspend authorization
}
\description{
Put rgoogleads into a de-authorized state. Instead of sending a token,
rgoogleads will send an API key. This can be used to access public
resources for which no Google sign-in is required. This is handy for using
rgoogleads in a non-interactive setting to make requests that do not
require a token. It will prevent the attempt to obtain a token
interactively in the browser. The user can configure their own API key
via \code{\link[=gads_auth_configure]{gads_auth_configure()}} and retrieve that key via
\code{\link[=gads_api_key]{gads_api_key()}}.
In the absence of a user-configured key, a built-in default key is used.
}
\seealso{
Other auth functions: 
\code{\link{gads_auth}()},
\code{\link{gads_auth_configure}()}
}
\concept{auth functions}
