% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_last_request_ids.R
\name{gads_customer_id_to_env}
\alias{gads_customer_id_to_env}
\title{Write customer id for error message}
\usage{
gads_customer_id_to_env(customer_id)
}
\arguments{
\item{customer_id}{Your client customer id}
}
\value{
only set customer id into env
}
\description{
Write customer id for error message
}
