% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_last_request_ids.R
\name{gads_customer_id_from_env}
\alias{gads_customer_id_from_env}
\title{Get customer id for error message}
\usage{
gads_customer_id_from_env()
}
\value{
only set customer id into env
}
\description{
Get customer id for error message
}
