% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_get_accessible_customers.R
\name{gads_get_accessible_customers}
\alias{gads_get_accessible_customers}
\title{Get all data of customers directly accessible by the user authenticating the call.}
\usage{
gads_get_accessible_customers()
}
\value{
List of your accessible accounts from top level
}
\description{
Get all data of customers directly accessible by the user authenticating the call.
}
\examples{
\dontrun{
accounts <- gads_get_accessible_customers()
}
}
