% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_customer.R
\name{gads_customer}
\alias{gads_customer}
\title{Get all information about Google Ads Customer}
\usage{
gads_customer(customer_id = getOption("gads.customer.id"), verbose = TRUE)
}
\arguments{
\item{customer_id}{Google Ads customer id}

\item{verbose}{Processing log output into console}
}
\value{
Google Ads customer data
}
\description{
Get all information about Google Ads Customer
}
\seealso{
\href{https://developers.google.com/google-ads/api/rest/common/search}{Method: SearchStream documentation}
}
