% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gads_auth.R
\name{gads_set_customer_id}
\alias{gads_set_customer_id}
\title{Set client customer id in current R session}
\usage{
gads_set_customer_id(customer_id)
}
\arguments{
\item{customer_id}{your client customer id}
}
\value{
only set options
}
\description{
Set client customer id in current R session
}
